#version 150

in vec3 Position;
in vec4 Color;

uniform float GameTime;
uniform mat4 ModelViewMat;
uniform mat4 ProjMat;

out vec4 vertexColor;

vec3 hslToRgb(float H, float S, float L) {
    float C = (1.0 - abs(2.0 * L - 1.0)) * S;  // Chroma
    float X = C * (1.0 - abs(mod(H / 60.0, 2.0) - 1.0));  // X value
    float m = L - C / 2.0;  // Lightness offset

    float r, g, b;

    // Hue is in the range [0, 360), and it's divided into 6 sectors, each corresponding to a color.
    if (H >= 0.0 && H < 60.0) {
        r = C;
        g = X;
        b = 0.0;
    } else if (H >= 60.0 && H < 120.0) {
        r = X;
        g = C;
        b = 0.0;
    } else if (H >= 120.0 && H < 180.0) {
        r = 0.0;
        g = C;
        b = X;
    } else if (H >= 180.0 && H < 240.0) {
        r = 0.0;
        g = X;
        b = C;
    } else if (H >= 240.0 && H < 300.0) {
        r = X;
        g = 0.0;
        b = C;
    } else {
        r = C;
        g = 0.0;
        b = X;
    }

    // Add the lightness offset (m) to each color channel
    r += m;
    g += m;
    b += m;

    // Return the final color as a vec3 (normalized to [0, 1] range)
    return vec3(r, g, b);
}

void main() {
    gl_Position = ProjMat * ModelViewMat * vec4(Position, 1.0);
    vertexColor = Color;
    
    float H = mod(GameTime*100,360);
    float S = 1.0;
    float L = 0.5;

    vec3 color = hslToRgb(H, S, L);

    // Remove white GUI highlight    opacity: 128/255
    if (Color == vec4(1,1,1,0.5019607843)) {
        if (abs(Position.y-225) > 20 || abs(Position.x-299) > 63) {
            vertexColor = vec4(0,0,0,0);
        } else {
            color = hslToRgb(mod(GameTime*1000000,360), 1.0, 0.5);
            vertexColor = vec4(color,0.2);
        }
    }
}
